<%
/*******************************************************************************
* Copyright (C) 2006 Ping Identity Corporation All rights reserved.
*
* This software is licensed under the Open Software License v2.1 (OSL v2.1).
*
* A copy of this license has been provided with the distribution of this
* software. Additionally, a copy of this license is available at:
* http://opensource.org/licenses/osl-2.1.php
*
******************************************************************************
*/
%>
<%@ page language="java" contentType="text/html; charset=ISO-8859-1"
    pageEncoding="ISO-8859-1"%>
<%!
	/**
	 * handleDefaultRequest method handles the SSO request. If the local
	 * session exists and the resumePath parameter is found, this method
	 * creates a PFTOKEN and redirects to the resumePath.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleDefaultRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);
		String cmd = request.getParameter(PARAM_CMD);

		// Get user attributes from session
		Map userInfo = (Map)session.getAttribute(USER_INFO);

		// Check userInfo again to see if the user is authenticated
		if((userInfo == null) || (userInfo.size() <= 0)) {
			// Check for isPassive
			if(isPassive(request)) {
				String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);
				response.sendRedirect(loginPage + "&error=SSO Error, IsPassive is true");
				return;
			}

			String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);
			if(resumePath != null) {
				loginPage += "&" + PARAM_CMD + "=" + cmd;
				loginPage += "&" + RESUME_PATH + "=" + resumePath;
			}
			response.sendRedirect(loginPage);
			return;
		}

		// The user is authenticated so store the attributes in session
		session.setAttribute(USER_INFO, userInfo);

		if(resumePath != null) {
			// Check for forceAuthn
			if(forceAuthentication(request)) {
				String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);
				session.invalidate();
				if(resumePath != null) {
					loginPage = loginPage + "&" + PARAM_CMD + "=" + cmd;
					loginPage = loginPage + "&" + RESUME_PATH + "=" + resumePath;
				}
				response.sendRedirect(loginPage + "&error=ForceAuthn is true");
				return;
			}

			// Create url for redirect
			String returnURL = getResumePathUrl(resumePath);
			String TargetResource = request.getParameter("TargetResource");
			if(TargetResource != null) {
				returnURL += "&TargetResource=" + TargetResource;
			}


			// The user has been authenticated so create PFTOKEN
			returnURL = setPFToken(request,response,returnURL,userInfo);

			// Redirect to url obtained earlier
			response.sendRedirect(returnURL);
		}
		else {

			// Redirect to the SP Sample Application Protected Page
			String mainpage = getIdpMainPageUrl();
			if(resumePath != null) {
				mainpage = mainpage + "?" + RESUME_PATH + "=" + resumePath;
			}
			response.sendRedirect(mainpage);
		}
	}

	/**
	 * handleSLORequest method is invoked to handle SLO requests
	 * coming from PingFederate. This function invalidates the local
	 * session (if exists) and redirect to the login page. If the 
	 * resumePath parameter exists, a logout PFTOKEN is sent with the 
	 * response back to PingFederate
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleSLORequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {

		Properties configProperties = getProperties(configFilePath);

		String resumePath = request.getParameter(RESUME_PATH);

		// Get HttpSession from request
		HttpSession session = request.getSession(false);

		if(session == null) {
			// If resume path exists, redirect. This will happen if there are multiple sso sessions in PingFederate
			if(resumePath != null) {
				response.sendRedirect(getResumePathUrl(resumePath));
				return;
			}
			else {
				// Redirect to login page. This will happen if the user performs a local logout before initiating SLO
				String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);

				if(resumePath != null) {
					loginPage = loginPage + "&error=Local session does not exist";
				}
	 	 		response.sendRedirect(loginPage);
				return;
			}
		}

		// Get user attributes from session
		Map userInfo = (Map)session.getAttribute(USER_INFO);

		if(userInfo == null) {
			// Redirect to login page.
			String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);
			if(resumePath != null) {
				loginPage = loginPage + "&error=Local session does not exist";
			}
 	 		response.sendRedirect(loginPage);
			return;
		}

		String returnURL = null;

		// Send Logout request via PFTOKEN in case we
		// have got the response from PingFederate server
		if(resumePath != null) {
			// Create url for redirect
			returnURL = getResumePathUrl(resumePath);
			returnURL = setLogoutPFToken(request, response, returnURL, userInfo, true);

		}
		else {
			// Resume path does not exist so simply redirect to login page
			returnURL = getIdpLoginPageUrl(LOGIN_SOURCE);
			returnURL += "&error=Successfully logged out";
		}

		session.invalidate();

		// Redirect to the url created earlier
		response.sendRedirect(returnURL);
	}

	/**
	 * handleLogoutRequest method is invoked to handle local logout.
	 * It simply invalidates the existing session and redirects
	 * to the resumePath or the login page.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleLogoutRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);

		if(session != null) {
			session.invalidate();
		}

		if(resumePath != null) {
			response.sendRedirect(getResumePathUrl(resumePath));
		}
		else {
			String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);
			response.sendRedirect(loginPage + "&error=Logged out from local session");
		}
	}

	/**
	 * handlePostLoginRequest method handles the login post with 
	 * credentials.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handlePostLoginRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);

		// Get user attributes from session
		Map userInfo = (Map)session.getAttribute(USER_INFO);

		// Check for credentials in request
		String userName = request.getParameter(USER_NAME);
		String password = request.getParameter(PASSWORD);

		if(userName != null) {
			// Login user and get attributes
			userInfo = authenticateUser(userName,password);
			if(userInfo != null) {
				// Add user attributes to session
				session.setAttribute(USER_INFO, userInfo);
				String returnURL = getIdpDefaultPageUrl();
				if(resumePath != null) {
					returnURL += "?" + RESUME_PATH + "=" + resumePath;
				}
				response.sendRedirect(returnURL);

			}
			else {
				String loginPage = getIdpLoginPageUrl(LOGIN_SOURCE);
				session.invalidate();
				if(resumePath != null) {
					loginPage = loginPage + "&" + RESUME_PATH + "=" + resumePath;
				}
				response.sendRedirect(loginPage + "&error=Invalid Login");
				return;
			}
		}

	}


%>
