<%
/*******************************************************************************
* Copyright (C) 2006 Ping Identity Corporation All rights reserved.
*
* This software is licensed under the Open Software License v2.1 (OSL v2.1).
*
* A copy of this license has been provided with the distribution of this
* software. Additionally, a copy of this license is available at:
* http://opensource.org/licenses/osl-2.1.php
*
******************************************************************************
*/
%>
<%@ page language="java" contentType="text/html; charset=ISO-8859-1"
    pageEncoding="ISO-8859-1"%>
<%!
	/**
	 * handleDefaultRequest method handles the SSO Request. It looks for
	 * a PFTOKEN and if found creates a local session based on that.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleDefaultRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
      	Properties configProperties = getProperties(configFilePath);

		String resumePath = request.getParameter(RESUME_PATH);

		HttpSession session = request.getSession(false);

		// Get user attributes from PFTOKEN as a Map object
		Map userInfo = parsePFToken(request, response);

		// Get userInfo from session
		if(userInfo == null || userInfo.size() == 0) {
			if(session != null) {
				userInfo = (Map)session.getAttribute(USER_INFO);
			}
		}

		// Store the attributes obtained from PFTOKEN in session
		session.setAttribute(USER_INFO, userInfo);

		String redirectURL = null;
		// Redirect to the SP Sample Application Protected Page
		if(resumePath != null) {
			redirectURL = resumePath;
		}
		else {
			redirectURL = getSpMainPageUrl();
		}

		response.sendRedirect(redirectURL);
	}

	/**
	 * handleSLORequest method is invoked to handle SLO requests
	 * coming from PingFederate. This function invalidates the local
	 * session (if exists) and redirect to the login page. If the 
	 * resumePath parameter exists, a logout PFTOKEN is sent with the 
	 * response back to PingFederate
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleSLORequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		Properties configProperties = getProperties(configFilePath);

		String resumePath = request.getParameter(RESUME_PATH);

		// Get HttpSession from request
		HttpSession session = request.getSession(false);

		//url to Error Page
		String errorPage = getSpErrorPageUrl();

		if(session == null) {
			// If resume path exists, redirect. This will happen if there are multiple sso sessions in PingFederate
			if(resumePath != null) {
				response.sendRedirect(getResumePathUrl(resumePath));
				return;
			}
			else {
				// Redirect to login page. This will happen if the user performs a local logout before initiating SLO
				String loginPage = getSpLoginPageUrl("main"); //$NON-NLS-1$

				loginPage += "&error=Local session does not exist";
	 	 		response.sendRedirect(loginPage);
				return;
			}
		}

		// Get sessionID from the request
		String userSessionID = request.getParameter(
			PFTokenConstants.SESSION_ID_PARAMETER);

		// Create url for redirect after performing logout
		String returnURL = null;

		if(resumePath != null) {
			returnURL = getResumePathUrl(resumePath);
			if(userSessionID != null) {
				// Send Logout request via PFTOKEN cookie or query
				returnURL = setLogoutPFToken(request, response, returnURL, userSessionID, true);

			}
		}
		else {
			returnURL = getSpLoginPageUrl(LOGIN_SOURCE);
			returnURL += "&error=Successfully logged out";
		}

		session.invalidate();	

		// Redirect to url created earlier
		response.sendRedirect(returnURL);

	}

	/**
	 * handleAccountLinkingRequest method is invoked to handle 
	 * Account Linking. If the local session does not exist, it
	 * redirects to the account linking login page. Once a session
	 * is established, this method sends the local user if to 
	 * PingFederate through PFTOKEN.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleAccountLinkingRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);

		// Get user attributes from session
		Map userInfo = (Map)session.getAttribute(USER_INFO);

		if((userInfo == null) || (userInfo.size() <= 0)) {
			String loginPage = getSpAccountLinkingPageUrl(LOGIN_SOURCE);
			if(resumePath != null) {
				loginPage += "&" + RESUME_PATH + "=" + resumePath;
			}
			response.sendRedirect(loginPage);
			return;
		}

		// Store the attributes obtained from PFTOKEN in session
		session.setAttribute(USER_INFO, userInfo);

		if(resumePath != null) {
			// Create url for redirect
			String returnURL = getResumePathUrl(resumePath);
			returnURL = setPFToken(request, response, returnURL, userInfo);

			// Redirect to url obtained earlier
			response.sendRedirect(returnURL);
		}
		else {

			// Redirect to the SP Sample Application Protected Page
			String mainpage = getIdpMainPageUrl();
			if(resumePath != null) {
				mainpage = mainpage + "?" + RESUME_PATH + "=" + resumePath;
			}
			response.sendRedirect(mainpage);
		}
	}

	/**
	 * handleLogoutRequest method is invoked to handle local logout.
	 * It simply invalidates the existing session and redirects
	 * to the resumePath or the login page.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handleLogoutRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);

		if(session != null) {
			session.invalidate();
		}

		if(resumePath != null) {
			response.sendRedirect(getResumePathUrl(resumePath));
		}
		else {
			String loginPage = getSpLoginPageUrl(LOGIN_SOURCE);
			response.sendRedirect(loginPage + "&error=Logged out from local session");
		}
	}


	/**
	 * handlePostLoginRequest method handles the login post with 
	 * credentials.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handlePostLoginRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);

		// Get user attributes from session
		Map userInfo = (Map)session.getAttribute(USER_INFO);

		// Check for credentials in request
		String userName = request.getParameter(USER_NAME);
		String password = request.getParameter(PASSWORD);

		if(userName != null) {
			// Login user and get attributes
			userInfo = authenticateUser(userName,password);
			if(userInfo != null) {
				// Add user attributes to session
				session.setAttribute(USER_INFO, userInfo);
				String returnURL = getSpDefaultPageUrl();
				if(resumePath != null) {
					returnURL += "?" + RESUME_PATH + "=" + resumePath;
				}
				response.sendRedirect(returnURL);

			}
			else {
				String loginPage = getSpLoginPageUrl(LOGIN_SOURCE);
				session.invalidate();
				if(resumePath != null) {
					loginPage = loginPage + "&" + RESUME_PATH + "=" + resumePath;
				}
				response.sendRedirect(loginPage + "&error=Invalid Login");
				return;
			}
		}

	}

	/**
	 * handlePostLoginAccountLinkingRequest method handles the login post with 
	 * credentials for account linking.
	 * @param request
	 * 				current user request
	 * @param response
	 * 				current user response
	 */
	public void handlePostLoginAccountLinkingRequest(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
		// Get HttpSession from request
		HttpSession session = request.getSession(false);
		
		String resumePath = request.getParameter(RESUME_PATH);

		// Get user attributes from session
		Map userInfo = (Map)session.getAttribute(USER_INFO);

		// Check for credentials in request
		String userName = request.getParameter(USER_NAME);
		String password = request.getParameter(PASSWORD);

		if(userName != null) {
			// Login user and get attributes
			userInfo = authenticateUser(userName,password);
			if(userInfo != null) {
				// Add user attributes to session
				session.setAttribute(USER_INFO, userInfo);
				String returnURL = getSpDefaultPageUrl();
				if(resumePath != null) {
					returnURL += "?" + RESUME_PATH + "=" + resumePath;
					returnURL += "&" + PARAM_CMD + "=" + PARAM_CMD_ACCOUNT_LINK;
				}
				response.sendRedirect(returnURL);

			}
			else {
				String loginPage = getSpAccountLinkingPageUrl(LOGIN_SOURCE);
				session.invalidate();
				if(resumePath != null) {
					loginPage = loginPage + "&" + RESUME_PATH + "=" + resumePath;
				}
				response.sendRedirect(loginPage + "&error=Invalid Login");
				return;
			}
		}

	}



%>
